Thank you for contributing to the species repo! Before submitting this PR, please make sure:

- [ ] That the branch of your PR is synced with the main branch of tomasstolker/species.
- [ ] To add and/or update the docstrings (i.e. parameters, returns, types, and descriptions).
- [ ] To add and/or update the typehints and typechecks.
- [ ] To run `black` on any files that have been adjusted (see black.readthedocs.io).
- [ ] That only text files have been included with the commits.

